@@ -44,7 +44,7 @@ class YoloHub:
     def prediction(self, image, yaml_file=None):
         return self.model.predict(image, yaml_file=yaml_file)
 
-    def view_model(self, save, file_format="pdf"):
+    def view_model(self, file_format="pdf"):
         try:
             from torchview import draw_graph
         except:
